local sti = require "libs/sti"

local origin = {}
local scale = 2.2

function love.load()
  -- uncomment the line below if using zerobrane debugging (http://notebook.kulchenko.com/zerobrane/love2d-debugging)
  -- if arg[#arg] == "-debug" then require("mobdebug").start() end

  map = sti("assets/maps/mymap.lua", {"box2d"})
  background1 = sti("assets/maps/mymap2.lua")
  background2 = sti("assets/maps/mymap3.lua")

  origin.x, origin.y = 50, 50

  -- physics example derived from love2d physics tutorial (https://love2d.org/wiki/Tutorial:Physics)

  love.physics.setMeter(64)
  world = love.physics.newWorld(0, 9.81*64, true)

  objects = {}
  objects.ball = {}

  objects.ball.body = love.physics.newBody(world, origin.x, origin.y, "dynamic")
  objects.ball.shape = love.physics.newCircleShape(20)
  objects.ball.fixture = love.physics.newFixture(objects.ball.body, objects.ball.shape, 1)
  map:box2d_init(world)
end

function love.update(dt)
  map:update(dt)
  background1:update(dt)
  background2:update(dt)

  if love.keyboard.isDown("right") then
    objects.ball.body:applyForce(100, 0)
  elseif love.keyboard.isDown("left") then
    objects.ball.body:applyForce(-100, 0)
  elseif love.keyboard.isDown("down") then
    objects.ball.body:applyForce(-0, 400)
	elseif love.keyboard.isDown("space") then
		objects.ball.body:applyForce(0, -800)
  elseif love.keyboard.isDown("up") then
    objects.ball.body:setPosition(50, origin.y)
    objects.ball.body:setLinearVelocity(0, 0)
  end

  world:update(dt)
end

function love.draw()
  dx = objects.ball.body:getX() - (love.graphics.getWidth() / 2) / scale
  dy = objects.ball.body:getY() - (love.graphics.getHeight() / 2) / scale

  dx1 = (objects.ball.body:getX() - (love.graphics.getWidth() / 2) / scale) * 0.7
  dy1 = (objects.ball.body:getY() - (love.graphics.getHeight() / 2) / scale) * 0.8

  dx2 = (objects.ball.body:getX() - (love.graphics.getWidth() / 2) / scale) * 0.5

  love.graphics.scale(scale)
  love.graphics.translate(-dx, -dy)

  background2:draw(200 -dx2, -dy - 50, scale, scale)
  background1:draw(200 -dx1, -dy1, scale, scale)
  map:draw(-dx, -dy, scale, scale)

  love.graphics.circle("fill", objects.ball.body:getX(), objects.ball.body:getY(), objects.ball.shape:getRadius())
end
